@@ -35,7 +35,7 @@ impl CompoundStyle {
     where
         D: Clone + Display,
     {
-        self.object_style.clone().apply(val)
+        self.object_style.apply(val)
     }
 
     /// Get an new instance of `CompoundStyle`
