@@ -2,8 +2,6 @@
 ///
 #[derive(thiserror::Error, Debug)]
 pub enum Error {
-    #[error("Crossterm error: {0}")]
-    Crossterm(#[from] crossterm::ErrorKind),
     #[error("IO error: {0}")]
     IO(#[from] std::io::Error),
 }
