@@ -65,14 +65,19 @@ pub struct MadSkin {
 impl Default for MadSkin {
     /// Build a customizable skin.
     ///
-    /// It's initialized with sensible gray level settings.
+    /// It's initialized with sensible gray level settings which should work
+    /// whatever the terminal colors.
+    ///
+    /// If you want a default skin and you already know if your terminal
+    /// is light or dark, you may use [MadSkin::default_light]
+    /// or [MadSkin::default_dark].
     fn default() -> Self {
         let mut skin = Self {
             paragraph: LineStyle::default(),
-            bold: CompoundStyle::new(Some(Color::White), None, Attribute::Bold.into()),
+            bold: CompoundStyle::with_attr(Attribute::Bold),
             italic: CompoundStyle::with_attr(Attribute::Italic),
             strikeout: CompoundStyle::with_attr(Attribute::CrossedOut),
-            inline_code: CompoundStyle::with_bg(gray(3)),
+            inline_code: CompoundStyle::with_fgbg(gray(17), gray(3)),
             code_block: LineStyle::default(),
             headers: Default::default(),
             scrollbar: ScrollBarStyle::new(),
@@ -90,15 +95,12 @@ impl Default for MadSkin {
             #[cfg(feature="special-renders")]
             special_chars: HashMap::new(),
         };
-        skin.code_block.set_bg(gray(3));
+        skin.code_block.set_fgbg(gray(17), gray(3));
         for h in &mut skin.headers {
             h.add_attr(Attribute::Underlined);
         }
         skin.headers[0].add_attr(Attribute::Bold);
         skin.headers[0].align = Alignment::Center;
-        skin.headers[0].set_fg(gray(22));
-        skin.headers[1].set_fg(gray(21));
-        skin.headers[2].set_fg(gray(20));
         skin
     }
 }
@@ -130,7 +132,38 @@ impl MadSkin {
             special_chars: HashMap::new(),
         }
     }
-    /// Set a common foregreound color for all header levels
+
+    /// Build a customizable skin with gray levels suitable when the terminal has
+    /// a dark background
+    ///
+    /// To determine whether the terminal is in light mode, you may use
+    /// the [terminal-light](https://docs.rs/terminal-light/) crate.
+    pub fn default_dark() -> Self {
+        let mut skin = Self::default();
+        skin.code_block.set_fgbg(gray(20), gray(5));
+        skin.inline_code.set_fgbg(gray(20), gray(5));
+        skin.headers[0].set_fg(gray(22));
+        skin.headers[1].set_fg(gray(21));
+        skin.headers[2].set_fg(gray(20));
+        skin
+    }
+
+    /// Build a customizable skin with gray levels suitable when the terminal has
+    /// a light background
+    ///
+    /// To determine whether the terminal is in light mode, you may use
+    /// the [terminal-light](https://docs.rs/terminal-light/) crate.
+    pub fn default_light() -> Self {
+        let mut skin = Self::default();
+        skin.code_block.set_fgbg(gray(3), gray(20));
+        skin.inline_code.set_fgbg(gray(4), gray(20));
+        skin.headers[0].set_fg(gray(0));
+        skin.headers[1].set_fg(gray(2));
+        skin.headers[2].set_fg(gray(4));
+        skin
+    }
+
+    /// Set a common foreground color for all header levels
     ///
     /// (it's still possible to change them individually with
     /// `skin.headers[i]`)
@@ -258,9 +291,9 @@ impl MadSkin {
         W: std::io::Write,
     {
         let text = self.area_text(markdown, area);
-        let mut view = TextView::from(&area, &text);
+        let mut view = TextView::from(area, &text);
         view.show_scrollbar = false;
-        Ok(view.write_on(w)?)
+        view.write_on(w)
     }
 
     /// do a `print!` of the given src interpreted as a markdown span
@@ -277,7 +310,7 @@ impl MadSkin {
     pub fn print_expander(&self, expander: TextTemplateExpander<'_, '_>) {
         let (width, _) = terminal_size();
         let text = expander.expand();
-        let fmt_text = FmtText::from_text(&self, text, Some(width as usize));
+        let fmt_text = FmtText::from_text(self, text, Some(width as usize));
         print!("{}", fmt_text);
     }
 
@@ -289,7 +322,7 @@ impl MadSkin {
     ) {
         let (width, _) = terminal_size();
         let text = expander.expand(template);
-        let fmt_text = FmtText::from_text(&self, text, Some(width as usize));
+        let fmt_text = FmtText::from_text(self, text, Some(width as usize));
         print!("{}", fmt_text);
     }
 
@@ -443,7 +476,7 @@ impl MadSkin {
                 self.paragraph.repeat_space(f, lpo)?;
                 for cell in cells {
                     write!(f, "{}", self.table.compound_style.apply_to("│"))?;
-                    self.write_fmt_composite(f, &cell, None, false)?;
+                    self.write_fmt_composite(f, cell, None, false)?;
                 }
                 write!(f, "{}", self.table.compound_style.apply_to("│"))?;
                 if with_right_completion {
